@@ -1,9 +1,9 @@
 package Sah::Schema::cryptoexchange;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-CryptoCurrency'; # DIST
-our $VERSION = '0.014'; # VERSION
+our $VERSION = '0.015'; # VERSION
 
 our $schema = [str => {
     summary => 'Cryptoexchange code, name, or safename',
@@ -43,7 +43,7 @@ Sah::Schema::cryptoexchange - Cryptoexchange code, name, or safename
 
 =head1 VERSION
 
-This document describes version 0.014 of Sah::Schema::cryptoexchange (from Perl distribution Sah-Schemas-CryptoCurrency), released on 2020-03-04.
+This document describes version 0.015 of Sah::Schema::cryptoexchange (from Perl distribution Sah-Schemas-CryptoCurrency), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -57,7 +57,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -79,15 +79,15 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # INVALID
+ ""  # INVALID
 
- undef  # INVALID
+ "foo"  # INVALID
 
- undef  # valid
+ "BX Thailand"  # valid, becomes "bx-thailand"
 
- undef  # valid
+ "BX-thailand"  # valid, becomes "bx-thailand"
 
- undef  # valid
+ "bx"  # valid, becomes "bx-thailand"
 
 =head1 DESCRIPTION
 
